@@ -1,5 +1,5 @@
 """
-An API to retrieve and read NFL Game Center JSON data.
+nflgame is an API to retrieve and read NFL Game Center JSON data.
 It can work with real-time data, which can be used for fantasy football.
 
 nflgame works by parsing the same JSON data that powers NFL.com's live
@@ -7,8 +7,8 @@ GameCenter. Therefore, nflgame can be used to report game statistics while
 a game is being played.
 
 The package comes pre-loaded with game data from every pre- and regular
-season game from 2009 up until August 28, 2012. Therefore, querying such data
-does not actually ping NFL.com.
+season game from 2009 up until the present (I try to update it every week).
+Therefore, querying such data does not actually ping NFL.com.
 
 However, if you try to search for data in a game that is being currently
 played, the JSON data will be downloaded from NFL.com at each request (so be
@@ -17,160 +17,60 @@ If you ask for data for a particular game that hasn't been cached to disk
 but is no longer being played, it will be automatically cached to disk
 so that no further downloads are required.
 
-nflgame requires Python 2.6 or Python 2.7. It does not (yet) work with
-Python 3.
+Here's a quick teaser to find the top 5 running backs by rushing yards in the
+first week of the 2013 season:
 
-Examples
-========
+    #!python
+    import nflgame
+    
+    games = nflgame.games(2013, week=1)
+    players = nflgame.combine_game_stats(games)
+    for p in players.rushing().sort('rushing_yds').limit(5):
+        msg = '%s %d carries for %d yards and %d TDs'
+        print msg % (p, p.rushing_att, p.rushing_yds, p.rushing_tds)
 
-Finding games
--------------
-Games can be selected in bulk, e.g., every game in week 1 of 2010::
+And the output is:
 
-    games = nflgame.games(2010, week=1)
+    L.McCoy 31 carries for 184 yards and 1 TDs
+    T.Pryor 13 carries for 112 yards and 0 TDs
+    S.Vereen 14 carries for 101 yards and 0 TDs
+    A.Peterson 18 carries for 93 yards and 2 TDs
+    R.Bush 21 carries for 90 yards and 0 TDs
 
-Or pin-pointed exactly, e.g., the Patriots week 17 whomping against the Bills::
+Or you could find the top 5 passing plays in the same time period:
 
-    game = nflgame.one(2011, 17, "NE", "BUF")
+    #!python
+    import nflgame
+    
+    games = nflgame.games(2013, week=1)
+    plays = nflgame.combine_plays(games)
+    for p in plays.sort('passing_yds').limit(5):
+        print p
 
-This season's (2012) pre-season games can also be accessed::
+And the output is:
 
-    pregames = nflgame.games(2012, kind='PRE')
+    (DEN, DEN 22, Q4, 3 and 8) (4:42) (Shotgun) P.Manning pass short left to D.Thomas for 78 yards, TOUCHDOWN. Penalty on BAL-E.Dumervil, Defensive Offside, declined.
+    (DET, DET 23, Q3, 3 and 7) (5:58) (Shotgun) M.Stafford pass short middle to R.Bush for 77 yards, TOUCHDOWN.
+    (NYG, NYG 30, Q2, 1 and 10) (2:01) (No Huddle, Shotgun) E.Manning pass deep left to V.Cruz for 70 yards, TOUCHDOWN. Pass complete on a fly pattern.
+    (NO, NO 24, Q2, 2 and 6) (5:11) (Shotgun) D.Brees pass deep left to K.Stills to ATL 9 for 67 yards (R.McClain; R.Alford). Pass 24, YAC 43
+    (NYG, NYG 20, Q1, 1 and 10) (13:04) E.Manning pass short middle to H.Nicks pushed ob at DAL 23 for 57 yards (M.Claiborne). Pass complete on a slant pattern.
 
-Find passing leaders of a game
-------------------------------
-Given some game, the player statistics can be easily searched. For example,
-to find the passing leaders of a particular game::
+If you aren't a programmer, then the
+[tutorial for non
+programmers](https://github.com/BurntSushi/nflgame/wiki/Tutorial-for-non-programmers:-Installation-and-examples)
+is for you.
 
-    for p in game.players.passing().sort("passing_yds"):
-        print p, p.passing_att, p.passing_cmp, p.passing_yds, p.passing_tds
+If you need help, please come visit us at IRC/FreeNode on channel `#nflgame`.
+If you've never used IRC before, then you can
+[use a web client](http://webchat.freenode.net/?channels=%23nflgame).
+(Enter any nickname you like, make sure the channel is `#nflgame`, fill in
+the captcha and hit connect.)
 
-Output::
-
-    T.Brady 35 23 338 3
-    R.Fitzpatrick 46 29 307 2
-    B.Hoyer 1 1 22 0
-
-See every player that made an interception
-------------------------------------------
-We can filter all players on whether they had more than zero defensive
-interceptions, and then sort those players by the number of picks::
-
-    for p in game.players.filter(defense_int=lambda x:x>0).sort("defense_int"):
-        print p, p.defense_int
-
-Output::
-
-    S.Moore 2
-    A.Molden 1
-    D.McCourty 1
-    N.Barnett 1
-
-Finding weekly rushing leaders
-------------------------------
-Sequences of players can be added together, and their sum can then be used
-like any other sequence of players. For example, to get every player
-that played in week 10 of 2009::
-
-    week10 = nflgame.games(2009, 10)
-    players = nflgame.combine(week10)
-
-And then to list all rushers with at least 10 carries sorted by rushing yards::
-
-    rushers = players.rushing()
-    for p in rushers.filter(rushing_att=lambda x: x > 10).sort("rushing_yds"):
-        print p, p.rushing_att, p.rushing_yds, p.rushing_tds
-
-And the final output::
-
-    A.Peterson 18 133 2
-    C.Johnson 26 132 2
-    S.Jackson 26 131 1
-    M.Jones-Drew 24 123 1
-    J.Forsett 17 123 1
-    M.Bush 14 119 0
-    L.Betts 26 114 1
-    F.Gore 25 104 1
-    J.Charles 18 103 1
-    R.Williams 20 102 0
-    K.Moreno 18 97 0
-    L.Tomlinson 24 96 2
-    D.Williams 19 92 0
-    R.Rice 20 89 1
-    C.Wells 16 85 2
-    J.Stewart 11 82 2
-    R.Brown 12 82 1
-    R.Grant 19 79 0
-    K.Faulk 12 79 0
-    T.Jones 21 77 1
-    J.Snelling 18 61 1
-    K.Smith 12 55 0
-    C.Williams 14 52 1
-    M.Forte 20 41 0
-    P.Thomas 11 37 0
-    R.Mendenhall 13 36 0
-    W.McGahee 13 35 0
-    B.Scott 13 33 0
-    L.Maroney 13 31 1
-
-You could do the same for the entire 2009 season::
-
-    players = nflgame.combine(nflgame.games(2009))
-    for p in players.rushing().sort("rushing_yds").limit(35):
-        print p, p.rushing_att, p.rushing_yds, p.rushing_tds
-
-And the output::
-
-    C.Johnson 322 1872 12
-    S.Jackson 305 1361 4
-    A.Peterson 306 1335 17
-    T.Jones 305 1324 12
-    M.Jones-Drew 296 1309 15
-    R.Rice 240 1269 7
-    R.Grant 271 1202 10
-    C.Benson 272 1118 6
-    D.Williams 210 1104 7
-    R.Williams 229 1090 11
-    R.Mendenhall 222 1014 7
-    F.Gore 206 1013 8
-    J.Stewart 205 1008 9
-    K.Moreno 233 897 5
-    M.Turner 177 864 10
-    J.Charles 165 861 5
-    F.Jackson 205 850 2
-    M.Barber 200 841 7
-    B.Jacobs 218 834 5
-    M.Forte 242 828 4
-    J.Addai 213 788 9
-    C.Williams 190 776 4
-    C.Wells 170 774 7
-    A.Bradshaw 156 765 7
-    L.Maroney 189 735 9
-    J.Harrison 161 735 4
-    P.Thomas 141 733 5
-    L.Tomlinson 221 729 12
-    Kv.Smith 196 678 4
-    L.McCoy 154 633 4
-    M.Bell 155 626 5
-    C.Buckhalter 114 624 1
-    J.Jones 163 602 2
-    F.Jones 101 594 2
-    T.Hightower 137 574 8
-
-Load data into Excel
---------------------
-Every sequence of Players can be easily dumped into a file formatted
-as comma-separated values (CSV). CSV files can then be opened directly
-with programs like Excel, Google Docs, Open Office and Libre Office.
-
-You could dump every statistic from a game like so::
-
-    game.players.csv('player-stats.csv')
-
-Or if you want to get crazy, you could dump the statistics of every player
-from an entire season::
-
-    nflgame.combine(nflgame.games(2010)).csv('season2010.csv')
+Failing IRC, the second fastest way to get help is to
+[open a new issue on the
+tracker](https://github.com/BurntSushi/nflgame/issues/new).
+There are several active contributors to nflgame that watch the issue tracker.
+We tend to respond fairly quickly!
 """
 
 try:
@@ -203,10 +103,10 @@ by GSIS ID. (The identifiers used by NFL.com GameCenter.)
 
 teams = [
     ['ARI', 'Arizona', 'Cardinals', 'Arizona Cardinals'],
-    ['ATL', 'Atlanta', 'Falcons', 'Atlana Falcons'],
+    ['ATL', 'Atlanta', 'Falcons', 'Atlanta Falcons'],
     ['BAL', 'Baltimore', 'Ravens', 'Baltimore Ravens'],
     ['BUF', 'Buffalo', 'Bills', 'Buffalo Bills'],
-    ['CAR', 'Carolina', 'Panthers', 'Caroline Panthers'],
+    ['CAR', 'Carolina', 'Panthers', 'Carolina Panthers'],
     ['CHI', 'Chicago', 'Bears', 'Chicago Bears'],
     ['CIN', 'Cincinnati', 'Bengals', 'Cincinnati Bengals'],
     ['CLE', 'Cleveland', 'Browns', 'Cleveland Browns'],
