@@ -3,6 +3,7 @@ import os
 import os.path as path
 import gzip
 import json
+import socket
 import sys
 import urllib2
 
@@ -149,11 +150,11 @@ class GameClock (object):
         self.clock = clock
 
         try:
-            self.__minutes, self.__seconds = map(int, self.clock.split(':'))
+            self._minutes, self._seconds = map(int, self.clock.split(':'))
         except ValueError:
-            self.__minutes, self.__seconds = 0, 0
+            self._minutes, self._seconds = 0, 0
         except AttributeError:
-            self.__minutes, self.__seconds = 0, 0
+            self._minutes, self._seconds = 0, 0
         try:
             self.__qtr = int(self.qtr)
             if self.__qtr >= 3:
@@ -194,9 +195,9 @@ class GameClock (object):
     def __cmp__(self, other):
         if self.__qtr != other.__qtr:
             return cmp(self.__qtr, other.__qtr)
-        elif self.__minutes != other.__minutes:
-            return cmp(other.__minutes, self.__minutes)
-        return cmp(other.__seconds, self.__seconds)
+        elif self._minutes != other._minutes:
+            return cmp(other._minutes, self._minutes)
+        return cmp(other._seconds, self._seconds)
 
     def __str__(self):
         """
@@ -406,6 +407,7 @@ class Game (object):
             self.__drives = _json_drives(self, self.home, self.data['drives'])
             self.drives = nflgame.seq.GenDrives(self.__drives)
             return self.drives
+        raise AttributeError
 
     def __sub__(self, other):
         return diff(other, self)
@@ -634,6 +636,8 @@ class Play (object):
         return self.playid == other.playid and self.desc == other.desc
 
     def __getattr__(self, name):
+        if name.startswith('__'):
+            raise AttributeError
         return 0
 
 
@@ -793,6 +797,8 @@ def _get_json_data(eid=None, fpath=None):
         return urllib2.urlopen(_json_base_url % (eid, eid), timeout=5).read()
     except urllib2.HTTPError:
         pass
+    except socket.timeout:
+        pass
     return None
 
 
